@@ -158,6 +158,8 @@ class GSPeerConnectionWatcherNew:
         self = connectionWatcher
         self.rtconfiList = []
         self.sio = socketio.AsyncClient()
+        self.peerConnections = None
+        self.gsmediaconsumer = None
         self.gsdbs = gsdbs
         self.onframe = onframe
         self.target = target
@@ -177,9 +179,14 @@ class GSPeerConnectionWatcherNew:
         async def connect():
             self.logger.info('connection established')
 
+        @self.sio.event
+        async def bjoined(id):
+            self.logger.info("broadcaster received")
+            await self.sio.emit("broadcaster", {"id": id, "target": self.target})
+
         @self.sio.event
         async def joined(id):
-            self.logger.info("joined")
+            self.logger.info("calling broadcaster")
             await self.sio.emit("broadcaster", {"id": id, "target": self.target})
 
         @self.sio.event
@@ -203,9 +210,9 @@ class GSPeerConnectionWatcherNew:
                         await self.ontrack(self.gsdbs, track, self.target)
                     if self.onframe is not None:
                         self.logger.info("on track received. onframe started")
-                        gsmediaconsumer = GSMediaConsumer(self.gsdbs, self.target, self.onframe)
-                        gsmediaconsumer.addTrack(track)
-                        await gsmediaconsumer.start()
+                        self.gsmediaconsumer = GSMediaConsumer(self.gsdbs, self.target, self.onframe)
+                        self.gsmediaconsumer.addTrack(track)
+                        await self.gsmediaconsumer.start()
 
             await self.peerConnections.setRemoteDescription(offer)
             await self.peerConnections.setLocalDescription(await self.peerConnections.createAnswer())
@@ -215,13 +222,21 @@ class GSPeerConnectionWatcherNew:
                                              "sdp": self.peerConnections.localDescription.sdp}})
 
         @self.sio.event
-        async def disconnect(id, target):
+        async def disconnect():
             self.logger.info("Socket connection list")
+            if self.peerConnections != None:
+                self.peerConnections.close()
+            if self.gsmediaconsumer != None:
+                await self.gsmediaconsumer.stop()
             await self.ontrackended(self.gsdbs, target)
 
         @self.sio.event
-        async def disconnectPeer(id, target):
+        async def disconnectPeer(id):
             self.logger.info("Camera connection list")
+            if self.peerConnections != None:
+                await self.peerConnections.close()
+            if self.gsmediaconsumer != None:
+                await self.gsmediaconsumer.stop()
             await self.ontrackended(self.gsdbs, target)
 
         if "localhost" in self.gsdbs.credentials["signalserver"]:
